#
# spec file for package kubelogin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubelogin
Version:        0.1.6
Release:        1.1
Summary:        Kubernetes client credential plugin implementing Azure authentication
License:        MIT
URL:            https://github.com/Azure/kubelogin
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.21
%{go_provides}

%description
A client-go credential (exec) plugin implementing azure authentication. This plugin provides features
that are not available in kubectl. It is supported on kubectl v1.11+

%prep
%setup -qa1

%build
%goprep github.com/Azure/kubelogin
export CGO_ENABLED=0
%gobuild -mod vendor -buildmode pie -ldflags "-X main.version=v%{version}" "${name}"

%install
%goinstall

%files
%{_bindir}/%{name}
%license LICENSE
%doc README.md

%changelog
* Sat Dec 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.6:
  * v0.1.6 release (#581)
  * Bump golang.org/x/crypto from 0.27.0 to 0.31.0 (#576)
  * add x5c header on pop call (#568)
  * remove snap since it's unsupported (#564)
* Tue Dec  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.5:
  * v0.1.5 release (#563)
  * Expose MSAL PoP for Consistent CSP Integration (#542)
  * Pre-emtive fix for the breaking GH Action. (#546)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azidentity (#534)
  * Bump github.com/golang-jwt/jwt/v4 from 4.5.0 to 4.5.1 (#543)
  * fix: fix fallback to Git tag if VCS is unavailable (#530)
  * Use AZURE_CONFIG_DIR in kubelogin command example (#522)
  * Bump golang.org/x/crypto from 0.25.0 to 0.26.0 (#505)
  * Bump golang.org/x/crypto from 0.24.0 to 0.25.0 (#490)
  * Bump ossf/scorecard-action from 2.0.6 to 2.4.0 (#498)
  * support of environment variable KUBECACHEDIR #500 (#501)
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.4:
  * doc: add 0.1.4 release note (#486)
  * Bump gopkg.in/dnaeon/go-vcr.v3 from 3.1.2 to 3.2.0 (#459)
  * Bump github.com/stretchr/testify from 1.8.4 to 1.9.0 (#444)
  * Bump github.com/spf13/cobra from 1.8.0 to 1.8.1 (#482)
  * Bump k8s.io/klog/v2 from 2.110.1 to 2.130.1 (#483)
  * chore: upgrade go to v1.21.11 to fix CVE-2024-24790 (#485)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azcore from 1.11.1
    to 1.12.0 (#478)
  * feat: declare go version directive with patch version (#476)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azidentity (#474)
* Tue Apr 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.3:
  * doc: prepare v0.1.3 (#456)
  * Bump golang.org/x/net from 0.21.0 to 0.23.0 (#451)
* Fri Apr 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.2:
  * prepare for v0.1.2 release (#450)
  * Bump github.com/golang-jwt/jwt/v5 from 5.2.0 to 5.2.1 (#443)
  * Bump github.com/google/uuid from 1.5.0 to 1.6.0 (#406)
  * Bump golang.org/x/crypto from 0.18.0 to 0.22.0 (#445)
  * fix: tidy go.mod and bump go version (#448)
  * Bump k8s.io/cli-runtime from 0.28.3 to 0.29.3 (#433)
  * Bump google.golang.org/protobuf from 1.30.0 to 1.33.0 (#430)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.1:
  * prepare for v0.1.1 release (#421)
  * Add PoP token support for ROPC flow (#412)
  * [StepSecurity] Apply security best practices (#404)
  * Adds Azure Developer CLI (azd) as a new login method (#398)
  * Bump golang.org/x/crypto from 0.17.0 to 0.18.0 (#392)
  * Bump github.com/AzureAD/microsoft-authentication-library-for-go
    (#391)
  * Changes in correlation with new GH Action Permission Changes.
    (#400)
  * Default branch is now main. (#390)
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.0:
  * v0.1.0 release (#388)
  * Bump github.com/google/uuid from 1.4.0 to 1.5.0 (#383)
  * fix: downgrade reuqired go version (#386)
  * Bump go.uber.org/mock from 0.3.0 to 0.4.0 (#385)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azcore from 1.8.0 to
    1.9.1 (#372)
  * Bump github.com/golang-jwt/jwt/v5 from 5.0.0 to 5.2.0 (#370)
  * Bump golang.org/x/crypto from 0.14.0 to 0.17.0 (#378)
  * Bump github.com/spf13/cobra from 1.7.0 to 1.8.0 (#359)
  * [library usage] Implement library token provider (#380)
  * [library usage] Refine internal token types (#379)
  * [library usage] Update module version usages (#377)
  * [library usage] Move modules under `pkg` to `pkg/internal`
    (#376)
* Sun Dec  3 2023 kastl@b1-systems.de
- Update to version 0.0.34:
  * feat: add 0.0.34 release change log (#369)
  * added armv7 support (#367)
  * added github token support (#366)
  * Bump github.com/google/uuid from 1.3.1 to 1.4.0 (#355)
  * Bump k8s.io/klog/v2 from 2.100.1 to 2.110.1 (#357)
  * feat(timeout): Implement customizable timeout for Azure CLI
    token retrieval in kubelogin get-token (#362)
  * bump golang to 1.21 (#356)
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 0.0.33:
  * 0.0.33 release (#354)
  * Bump github.com/stretchr/testify from 1.8.2 to 1.8.4 (#348)
  * Bump github.com/google/go-cmp from 0.5.9 to 0.6.0 (#349)
  * Bump k8s.io/cli-runtime from 0.28.2 to 0.28.3 (#351)
  * Bump k8s.io/cli-runtime from 0.27.2 to 0.28.2 (#340)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azidentity (#346)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azcore from 1.6.1 to
    1.8.0 (#344)
  * Bump golang.org/x/net from 0.10.0 to 0.17.0 (#347)
  * Update install.md (#342)
  * use the adal library for spn when --legacy is specified (#338)
  * Add 1P client/server app IDs to docs (#336)
  * Bump github.com/google/uuid from 1.3.0 to 1.3.1 (#334)
* Thu Oct 26 2023 kastl@b1-systems.de
- Update to version 0.0.32:
  * v0.0.32 release (#332)
  * Add PoP token support to interactive+spn
    get-token/convert-kubeconfig flows (#319)
  * Bump k8s.io/apimachinery from 0.27.3 to 0.27.4 (#310)
  * Bump golang.org/x/crypto from 0.11.0 to 0.12.0 (#315)
  * Fixed typo in top header for convert-kubeconfig documentation
    (#323)
* Thu Oct 26 2023 kastl@b1-systems.de
- refactor `_service` file to use obs_scm
- Update to version 0.0.31:
  * Changelog for 0.0.31 release. (#307)
  * upgrade klog from v1 to v1 (#306)
  * Bump k8s.io/apimachinery from 0.27.2 to 0.27.3 (#297)
  * Bump golang.org/x/crypto from 0.10.0 to 0.11.0 (#303)
  * Add chocolatey installation instructions (#299)
  * docs: Use asdf-plugins index instead of hard coded repo (#298)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azcore from 1.6.0 to
    1.6.1 (#292)
  * Bump golang.org/x/crypto from 0.9.0 to 0.10.0 (#294)
* Fri Jun 30 2023 rombert@apache.org
- Update to version 0.0.30:
  * fixed the changelog (#293)
  * release v0.0.30 (#291)
  * update go to address CVE (#290)
  * Azidentity migration for service principal token (#287)
  * Bump k8s.io/cli-runtime from 0.27.1 to 0.27.2 (#285)
  * Bump k8s.io/apimachinery from 0.27.1 to 0.27.2 (#283)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azidentity (#278)
  * Adding installHint field to kubeconfigs that have been converted to the exec format (#282)
  * Bump golang.org/x/crypto from 0.8.0 to 0.9.0 (#277)
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azcore from 1.5.0 to 1.6.0 (#274)
  * removed repetitve code and added test matrix (#268)
  * Bump github.com/Azure/go-autorest/autorest from 0.11.28 to 0.11.29 (#273)
  * Bump k8s.io/cli-runtime from 0.26.3 to 0.27.1 (#262)
  * added verbose logging in convert-kubeconfig (#272)
  * Bump github.com/AzureAD/microsoft-authentication-library-for-go
  * Bump github.com/Azure/azure-sdk-for-go/sdk/azcore from 1.1.1 to 1.5.0 (#249)
  * update doc for v0.0.29 (#270)
  * v0.0.29 release (#269)
  * Bump github.com/Azure/go-autorest/autorest/adal from 0.9.22 to 0.9.23 (#265)
  * Update devicecode.md (#266)
  * Fix merge conflicts and breaking changes in PR 221 (#264)
  * add --azure-config-dir in convert-kubeconfig subcommand (#263)
  * Bump k8s.io/client-go from 0.26.3 to 0.27.1 (#258)
  * return error when specified context is not found (#261)
  * add --context support in convert subcommand (#260)
  * How to install kubelogin with asdf tool manager (#256)
  * Bump k8s.io/apimachinery from 0.26.3 to 0.27.1 (#257)
  * Add reference to a context. (#253)
  * Add codecov badge to this repo. (#252)
  * Bump golang.org/x/crypto from 0.7.0 to 0.8.0 (#250)
  * Bump github.com/spf13/cobra from 1.6.1 to 1.7.0 (#245)
  * ignore docs and readme on some workflows (#248)
  * update readme and docs (#247)
  * revamp the website (#246)
  * Bump k8s.io/cli-runtime from 0.26.2 to 0.26.3 (#237)
  * Document scoop installation option (#242)
  * added inline toc (#244)
  * Feature/addtests (#238)
  * adding github pages (#241)
  * Create .github/workflows/jekyll-gh-pages.yml
  * Bump k8s.io/client-go from 0.26.2 to 0.26.3 (#234)
  * refactor windows install doc (#233)
  * Bump golang.org/x/crypto from 0.6.0 to 0.7.0 (#230)
  * Enable Code Cov for this repo. (#229)
  * changelog for v0.0.28 (#225)
  * Bump k8s.io/cli-runtime from 0.26.1 to 0.26.2 (#218)
  * Bump k8s.io/apimachinery from 0.26.1 to 0.26.2 (#217)
  * Bump golang.org/x/crypto from 0.0.0-20220722155217-630584e8d5aa to 0.6.0 (#211)
  * Bump golang.org/x/net from 0.3.1-0.20221206200815-1e63c2f08a10 to 0.7.0 (#214)
  * Bump github.com/Azure/go-autorest/autorest from 0.11.27 to 0.11.28 (#212)
  * Bump github.com/spf13/cobra from 1.6.0 to 1.6.1 (#213)
  * Bump github.com/Azure/go-autorest/autorest/adal from 0.9.21 to 0.9.22 (#204)
  * Bump k8s.io/cli-runtime from 0.24.2 to 0.26.1 (#208)
  * Bump golang.org/x/text from 0.3.7 to 0.3.8 (#209)
  * ci: remove snapstore publish step from push action (#210)
  * document the default device code login doesn't work with conditional … (#202)
  * fix: set package ecosystem (#203)
  * Create dependabot.yml (#201)
  * v0.0.27 release (#200)
  * update go-restful mod. (#198)
  * added binaries for win/arm64 (#195)
  * added installation from winget (#194)
  * publish v0.0.26 (#190)
  * Fix/release tagging (#189)
  * releasing v0.0.26 (#187)
  * Possible enhancement - Add changelog for this repo for automating release tags. ❤️☕️💡 (#177)
  * update workflow to build and publish snap package (#183)
  * build: add support for Ubuntu snap package (#182)
  * Enable CodeQL Analysis. (#179)
  * Add go reference to the repo. (#181)
  * Go-report and cli flare addition. (#178)
  * update release archives to omit unnecessary file (#176)
  * update doc with interactive login index (#175)
  * Add support of env var convention used by azure sdk (#174)
  * added golangci-lint (#168)
  * Fix clear default kubeconfig (#158)
  * gofmt -s -w . (#157)
  * update actions (#156)
* Mon Dec 12 2022 Robert Munteanu <rombert@apache.org>
- Ensure the downloaded archive is identical with the one generated
  by `osc service runall download_files`
* Mon Dec 12 2022 rombert@apache.org
- Update to version 0.0.24:
  * Revert following commits as the original assumption where devicelogin shouldn't work in non-interactive mode is invalid (#155)
  * Close code block (#154)
  * Enable kubectl version lower than 1.22 to work though without triggering exit under devicelogin mode (#152)
  * fixed a bug where kubelogin get-token always expects KUBERNETES_EXEC_INFO env var (#151)
  * Implemented web browser interactive login flow (#135)
  * Gaojing/devicelogin exit when interactivemode never (#145)
  * support client.authentication.k8s.io/v1
  * remove token cache for azurecli login (#142)
  * Add appending slash to oidc-issuer-url (#138)
  * Update objectId to id on Line 90 (#133)
  * Add how to write secret permantly into kubeconfig (#132)
  * Support encrypted client certificates for service principal login (#126)
  * Update README.md - Added Windows setup instructions (#128)
  * disregard tenantID from input kubeconfig when convert to azurecli (#124)
  * pass in tenantID to azurecli (#122)
  * Add platform information to `--version` (#117)
  * unit tests no longer touch default kubeconfig (#113)
  * update dependency and go1.18 (#97)
  * feat: Add ability to use env names of TF Azure provider (#110)
  * fixed a bug where token cache dir isn't effective (#111)
  * added --token-cache-dir support in convert-kubeconfig (#105)
  * add support of the rest of login methods to exec input (#103)
  * refactor the convert.go and added some unit tests
* Tue Jul 12 2022 Robert Munteanu <rombert@apache.org>
- Initial packaging of version 0.0.14
